@@ -10,15 +10,28 @@
 check_epanet_error <- function( rv ){
 	
 	if( !is.integer(rv)) stop("rv must be integer")
+
+    goodMsg <- NA
+	#try(goodMsg <- ENgeterror(rv))
 	
 	if( rv == 0){
 		return()
 	}  else if( rv > 100){
 		# return values greater than 100 are fatal errors
-		msg <- paste("epanet error ", rv)
+		if( is.na(goodMsg)){
+		    msg <- paste("epanet error ", rv)
+		} else {
+			msg <- goodMsg
+		}
 		stop(msg)
 	} else if( rv <= 100 ){
-		msg <- paste("epanet warning ", rv)
+		# return value 100 or less are warnings; continue evaluating
+		if (is.na(goodMsg)){
+		  # unable to obtain a good message so just return the error code
+		  msg <- paste("epanet warning ", rv)
+		} else {
+			msg <- goodMsg
+		}
 		warning(msg)
 	}
 }
